@@ -1,12 +1,12 @@
 ######################################################################
 # attach.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: attach.inc.pl,v 1.77 2007/07/15 07:40:09 papu Exp $
+# $Id: attach.inc.pl,v 1.106 2011/04/13 08:42:38 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
+# "PyukiWiki" version 0.1.8-p5 $$
 # Author: Nekyo
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
+# Copyright (C) 2004-2011 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2011 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -16,6 +16,9 @@
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
+# 2010/11/17: 󥿡б
+# 2010/10/24: 
+######################################################################
 
 #use strict;
 use CGI qw(:standard);
@@ -24,6 +27,9 @@ use Digest::MD5 qw(md5_hex);
 # if your system has not Digest::MD5, swap comment.
 use File::MMagic;
 
+# add 0.1.8
+require "plugin/counter.inc.pl";
+
 @magic_files=(
 
 
@@ -83,7 +89,7 @@ my %mime = (
 	'\.(au|snd)'		=> "audio/basic|audio",
 
 
-	'\.mmf'				=> "application/vnd.smaf|SMAF", #Voda/au/Tu-Ka
+	'\.mmf'				=> "application/vnd.smaf|SMAF", #SoftBank(not iphone)/au
 
 
 	'\.bmp'				=> "image/bmp|bitmap",
@@ -455,6 +461,11 @@ sub code_convert {
 	return &$funcp(@_);
 }
 
+sub plugin_counter_do {
+	my $funcp = $::functions{"plugin_counter_do"};
+	return &$funcp(@_);
+}
+
 sub new
 {
 	my $this = bless {};
@@ -482,9 +493,16 @@ sub open
 	my $filename=$this->{file};
 
 
+	if($::AttachCounter > 0) {
+		my $pg=$this->{page};
+		my $fn=$this->{file};
+		&plugin_counter_do("attach\_$pg\_$fn","w");
+	}
+
+
+
 	if($filename=~/[\x81-\xfe]/) {
-		if($ENV{HTTP_USER_AGENT}=~/Opera/) {
-			$filename=&code_convert(\$filename,"utf8",$::defaultcode);
+		if($ENV{HTTP_USER_AGENT}=~/Opera/ || $ENV{HTTP_USER_AGENT} =~/Chrome/) {			$filename=&code_convert(\$filename,"utf8",$::defaultcode);
 			$filename=qq(filename="$filename");
 			$filename=~s/%2e/\./g;
 		} elsif($ENV{HTTP_USER_AGENT}=~/MSIE/) {
@@ -496,6 +514,7 @@ sub open
 	} else {
 		$filename=qq(filename="$filename");
 	}
+
 	$http_header=$query->header(
 		-type=>"$this->{type}",
 		-Content_disposition=>"attachment; $filename",
@@ -511,6 +530,7 @@ sub open
 	my $buffer;
 	print $buffer while (read(FILE, $buffer, 4096));
 	close(FILE);
+
 	exit;
 }
 
@@ -525,6 +545,17 @@ sub info
 	my $info = $this->toString(1, 0);
 	my %retval;
 
+
+	my $counterstring;
+	if($::AttachCounter > 0) {
+		my $pg=$::form{refer};
+		my $fn=$this->{file};
+		my %attach_counter=&plugin_counter_do("attach\_$pg\_$fn","r");
+		$counterstring=<<EOM;
+ <dd>$::resource{attach_plugin_msg_dlcount}: $::resource{attach_plugin_msg_dlcount_total}: $attach_counter{total} $::resource{attach_plugin_msg_dlcount_today}: $attach_counter{today} $::resource{attach_plugin_msg_dlcount_yesterday}: $attach_counter{yesterday}</dd>
+EOM
+	}
+
 	$retval{msg} = "\t$::resource{attach_plugin_msg_info}";
 	$retval{body} =<<EOD;
 <p class="small">
@@ -539,7 +570,7 @@ sub info
  <dd>$::resource{attach_plugin_msg_filesize}: $this->{size_str} ($this->{size} bytes)</dd>
  <dd>Content-type: $this->{type}</dd>
  <dd>Magic: $this->{magic}</dd>
- <dd>$::resource{attach_plugin_msg_date}: $this->{time_str}</dd>
+ <dd>$::resource{attach_plugin_msg_date}: $this->{time_str}</dd>$counterstring
 </dl>
 EOD
 
