@@ -1,12 +1,12 @@
 ######################################################################
 # sbookmark.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: sbookmark.inc.pl,v 1.12 2007/07/15 07:40:09 papu Exp $
+# $Id: sbookmark.inc.pl,v 1.36 2011/01/25 03:11:15 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
+# "PyukiWiki" version 0.1.8-p2 $$
 # Author: Nekyo
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
+# Copyright (C) 2004-2011 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2011 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -232,3 +232,5 @@ sub plugin_sbookmark_convert {
 EOD
 }
 1;
+__END__
+
